<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\CategoriesRequestValidation;
use App\Repositories\CategoriesRepository;
use Illuminate\Http\Request;

class CategoriesController extends Controller
{
    private $categoriesRepository;

    public function __construct(CategoriesRepository $categoriesRepository)
    {
        $this->categoriesRepository = $categoriesRepository;
    }

    public function index()
    {
        $rows = $this->categoriesRepository->index();
        return view('admin.categories.index', compact('rows'));
    }

    public function edit($id)
    {
        $row = $this->categoriesRepository->show($id);
        return view('admin.categories.edit', compact('row'));
    }

    public function update(CategoriesRequestValidation $requestValidation, $id)
    {
        $requestValidation->validated();

        $this->categoriesRepository->update($id);
        success_toast();
        return redirect()->route('categories.index');
    }

    public function create(){
        return view('admin.categories.create');
    }
    public function store(CategoriesRequestValidation $requestValidation)
    {
        $requestValidation->validated();
        $this->categoriesRepository->store();
        toast('تم الإنشاء بنجاح', 'success');
        return redirect()->route('categories.index');
    }

    public function destroy($id)
    {
        $this->categoriesRepository->destroy($id);
        success_toast();
        return redirect()->route('categories.index');
    }

}
