<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\CategoriesRepository;
use App\Repositories\CourseDayRepository;
use App\Repositories\CoursesRepository;
use App\Repositories\FarouzRepository;
use App\Repositories\StudentsRepository;
use Illuminate\Http\Request;

class CoursesController extends Controller
{
    private $coursesRepository;
    private $categoriesRepository;
    private $courseDayRepository;
    private $studentsRepository;


    public function __construct(CoursesRepository $coursesRepository, CategoriesRepository $categoriesRepository, CourseDayRepository $courseDayRepository, StudentsRepository $studentsRepository
    )
    {
        $this->coursesRepository = $coursesRepository;
        $this->categoriesRepository = $categoriesRepository;
        $this->courseDayRepository = $courseDayRepository;
        $this->studentsRepository = $studentsRepository;

    }

    public function index()
    {
        $rows = $this->coursesRepository->index();

        return view('admin.courses.index', compact('rows'));
    }

    public function create()
    {
        $categories = $this->categoriesRepository->index();
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];
        return view('admin.courses.create', compact('categories', 'days'));
    }

    public function getTimeDive(Request $request)
    {
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];

        $time_div = view('admin.courses.times', compact('days'))->render();
        return response()->json(['value' => true, 'time_div' => $time_div]);
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'category_id' => 'required',
            'price' => 'required',
            'start_date' => 'required',
            'end_date' => 'required|after:start_date',
            'image' => 'required|image',
            'day_name' => 'required',
            'from_hour' => 'required',
            'to_hour' => 'required',
        ]);
        $this->coursesRepository->store();

        success_toast();
        return redirect()->route('courses.index');

    }


    public function destroy($id)
    {

        $this->coursesRepository->destroy($id);

        success_toast();
        return redirect()->back();
    }

    public function edit($id)
    {
        $categories = $this->categoriesRepository->index();
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];
        $row = $this->coursesRepository->show($id);

        $course_days = $this->courseDayRepository->index($id);
        return view('admin.courses.edit', compact('categories', 'row', 'days', 'course_days'));
    }

    public function delete_course_day($id)
    {

        $this->courseDayRepository->destroy($id);
        success_toast();
        return redirect()->back();

    }

    public function update_course_day($id)
    {

        $this->validate(\request(), [
            'day_name' => 'required',
            'from_hour' => 'required',
            'to_hour' => 'required'
        ]);


        $this->courseDayRepository->update($id);
        success_toast();
        return redirect()->back();
    }

    public function create_course_day($course_id)
    {
        $this->courseDayRepository->store($course_id);
        success_toast();
        return redirect()->back();
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'category_id' => 'required',
            'price' => 'required',
            'start_date' => 'required',
            'end_date' => 'required|after:start_date',
            'image' => 'image',


        ]);
        $this->coursesRepository->update($id);

        success_toast();
        return redirect()->route('courses.index');
    }

    public function show($id)
    {
        $row = $this->coursesRepository->show($id);
        $students = $this->coursesRepository->students($id);
        $documents = $this->coursesRepository->documents($id);


        return view('admin.courses.show', compact('row', 'students', 'documents'));
    }

    public function update_course_zoom(Request $request, $course_id)
    {
        $this->validate($request, [
            'zoom_link' => 'required'
        ]);
        $this->coursesRepository->update_course_zoom($course_id);
        success_toast();
        return redirect()->back();
    }

    public function attach_pdf($course_id)
    {
        $this->validate(\request(),[
            'document'=>'required',
            'document_name_ar'=>'required',
            'document_name_en'=>'required'
        ]);
        $this->coursesRepository->attach_pdf($course_id);
        success_toast();
        return redirect()->back();
    }
    public function delete_pdf($pdf_id){
        $this->coursesRepository->delete_pdf($pdf_id);
        success_toast();
        return redirect()->back();
    }
    public function update_pdf($pdf_id){
        $this->validate(\request(),[
            'document_name_ar'=>'required',
            'document_name_en'=>'required',
            'document'=>'required',
        ]);
        $this->coursesRepository->update_pdf($pdf_id);
        success_toast();
        return redirect()->back();
    }
}
