<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use App\Models\Country;
use App\Models\ModeratorsLog;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use RealRashid\SweetAlert\Facades\Alert;

class HomeController extends Controller
{
    public function login()
    {
        if (\Auth::guard('admin')->check()) {
            return redirect()->route('admin');
        }
        return view('admin.auth.login');

    }


    public function authenticate(Request $request)
    {

        if (\Auth::guard('admin')->attempt(['email' => $request['email'], 'password' => $request['password'], 'status' => 'active'])) {

            toast('مرحبا بكم في لوحة التحكم', 'success', 'left');

            return redirect()->route('admin');
        } else {

            Alert::error('خطأ في البيانات', 'البريد الألكتروني أو الرقم السري خطأ');

            return redirect()->back();
        }
    }

    public function index()
    {


        return view('admin.auth.index');

    }

    public function admin_logout()
    {



        \Auth::guard('admin')->logout();
        toast('تم تسجيل الخروج بنجاح', 'success', 'top-left');

        return redirect()->route('admin_login');
    }

    public function admin_profile()
    {
        $row = \auth()->guard('admin')->user();

        return view('admin.admin.own_profile', compact('row'));
    }

    public function update_own_profile(Request $request)
    {
        $row = \auth()->guard('admin')->user();

        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:admins,email,' . $row->id,
            'mobile' => 'required|unique:admins,mobile,' . $row->id,
            'image' => 'image',

        ], [
            'name.required' => 'برجي ادخال الاسم',
            'email.required' => 'يرجي ادخال البريد الألكتروني',
            'email.email' => 'يرجي ادخال البريد الألكتروني بطريقة صحيحة',
            'email.unique' => 'هذا البريد مستخدم من قبل',
            'mobile.required' => 'يرجي ادخال رقم الجوال',
            'mobile.unique' => 'رقم الجوال مستخدم من قبل',
            'image.image' => 'يرجي ارفاق صورة',

        ]);

        $row->name = $request['name'];
        $row->email = $request['email'];
        $row->mobile = $request['mobile'];
        if ($request->password) $row->password = bcrypt($request['password']);
        if ($request->hasFile('image')) $row->setImageAttribute();
        $row->update();
        success_toast();
        return redirect()->back();

    }
}
