<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\DeviceToken;
use App\Models\Notification;
use App\Models\Token;
use App\Repositories\NotificationsRepository;
use App\Repositories\StudentsRepository;
use App\Repositories\StudentsSubscribersRepository;
use App\User;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;

class NotificationsController extends Controller
{


    private $notificationsRepository;
    /**
     * @var StudentsRepository
     */
    private $studentsRepository;
    /**
     * @var StudentsSubscribersRepository
     */
    private $studentsSubscribersRepository;

    public function __construct(NotificationsRepository $notificationsRepository, StudentsRepository $studentsRepository, StudentsSubscribersRepository $studentsSubscribersRepository)
    {
        $this->notificationsRepository = $notificationsRepository;
        $this->studentsRepository = $studentsRepository;
        $this->studentsSubscribersRepository = $studentsSubscribersRepository;
    }

    public function index()
    {
        $all_students = $this->studentsRepository->index();
        $all_subscribed_students = $this->studentsSubscribersRepository->index();
        return view('admin.notifications.index', compact('all_students', 'all_subscribed_students'));
    }

    public function all_student_notifications(Request $request)
    {
        $this->validate($request, [
            'body_ar' => 'required',
            'body_en' => 'required',

        ], [
            'body_ar.required' => 'برجاء ادخال محتوي الإشعار ',
            'body_en.required' => 'برجاء ادخال محتوي الاشعار',

        ]);
        if (isset($request['students']) && count($request['students']) > 0) {
            foreach ($request['students'] as $user) {

                $this->notificationsRepository->saveNotification($user, $request['body_ar'], $request['body_en'], 'admin');
            }
        } else {
            foreach ($this->studentsRepository->index() as $user) {
                $this->notificationsRepository->saveNotification($user->id, $request['body_ar'], $request['body_en'], 'admin');
            }
        }
        success_toast();
        return redirect()->back();
    }

    public function all_subscribed_student_notifications(Request $request)
    {
        $this->validate($request, [
            'body_ar' => 'required',
            'body_en' => 'required',

        ], [
            'body_ar.required' => 'برجاء ادخال محتوي الإشعار ',
            'body_en.required' => 'برجاء ادخال محتوي الاشعار',

        ]);
        if (isset($request['students']) && count($request['students']) > 0) {
            foreach ($request['students'] as $user) {

                $this->notificationsRepository->saveNotification($user, $request['body_ar'], $request['body_en'], 'admin');
            }
        } else {
            foreach ($this->studentsSubscribersRepository->index() as $user) {
                $this->notificationsRepository->saveNotification($user->id, $request['body_ar'], $request['body_en'], 'admin');
            }
        }
        success_toast();
        return redirect()->back();
    }

    public function send_course_notifications($course_id, Request $request)
    {
        $this->validate($request, [
            'body_ar' => 'required',
            'body_en' => 'required'
        ]);

        $students = $this->studentsSubscribersRepository->course_students($course_id);
        foreach ($students as $student) {

            $this->notificationsRepository->saveNotification($student->id, $request['body_ar'], $request['body_en'], 'admin');

        }
        success_toast();
        return redirect()->back();


    }

}
