<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\RevisionRequestsRepositories;
use App\Repositories\SendEmailRepositories;
use Illuminate\Http\Request;

class RevisionRequestsController extends Controller
{

    /**
     * @var RevisionRequestsRepositories
     */
    private $revisionRequests;
    /**
     * @var SendEmailRepositories
     */
    private $sendEmail;

    public function __construct(RevisionRequestsRepositories $revisionRequests, SendEmailRepositories $sendEmail)
    {
        $this->revisionRequests = $revisionRequests;
        $this->sendEmail = $sendEmail;
    }


    public function send_mail_pdf(Request $request)
    {
        $this->sendEmail->send_email($request->email, $request->text, $request->document);
        success_toast();
        return redirect()->back();
    }


    public function index()
    {
        $status = ['waiting' => 'جديد', 'finished' => 'منتهي', 'paid' => 'مدفوع'];
        $payment_type = ['visa' => 'فيزا', 'bank' => 'تحويل بنكى', 'paypal' => 'باى بال', 'zbony' => 'زبونى', 'sala' => 'سلة'];
        $rows = $this->revisionRequests->index();
        return view('admin.revision_requests.index', compact('rows', 'status', 'payment_type'));
    }


    public function create()
    {
        return view('admin.revision_requests.create');
    }

    public function store(Request $request)
    {
        //
    }


    public function show($id)
    {
        $row = $this->revisionRequests->show($id);
        $status = ['waiting' => 'جديد', 'finished' => 'منتهي', 'paid' => 'مدفوع'];
        $payment_type = ['visa' => 'فيزا', 'bank' => 'تحويل بنكى', 'paypal' => 'باى بال', 'zbony' => 'زبونى', 'sala' => 'سلة'];

        return view('admin.revision_requests.show', compact('row', 'status', 'payment_type'));
    }

    public function edit($id)
    {
        $row = $this->revisionRequests->show($id);
        return view('admin.revision_requests.edit', compact('row'));
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'status' => 'required'
        ]);
        $this->revisionRequests->update($id);
        success_toast();
        return redirect()->route('revision_requests.index');
    }


    public function destroy($id)
    {
        $this->revisionRequests->destroy($id);
        success_toast();
        return redirect()->back();
    }

}
