<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\RevisionPriceResource;
use App\Http\Resources\RevisionRequestResource;
use App\Models\RevisionPrice;
use App\Models\RevisionRequest;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;
use JWTAuth;

class RevisionPricesController extends Controller
{

    public function revision_prices(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = RevisionPrice::latest()->get();
        return RevisionPriceResource::collection($rows)->additional(['value' => true,'code'=>200]);

    }

    public function add_revision_request(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'revision_price_id' => 'required|exists:revision_prices,id',
//            'payment_type' => 'required|in:visa,bank,paypal,zbony,sala',
            'name' => 'required',
            'email' => 'required|email',
            'body' => 'required',
            'document' => 'required',
//            'transfer_image' => 'required_if:payment_type,bank|image',
//            'bank_id' => 'required_if:payment_type,bank|exists:banks,id',
//            'bank_name' => 'required_if:payment_type,bank',
//            'bank_account_number' => 'required_if:payment_type,bank',
//            'bank_iban_number' => 'required_if:payment_type,bank'
        ]);
        if ($validator->passes()) {

            $revision = new RevisionRequest();
            $revision->user_id = $user->id;
            $revision->name = $request->name;
            $revision->email = $request->email;
            $revision->body = $request->body;
            $revision->completed = 'false';
            $revision->revision_price_id = $request->revision_price_id;
//            if ($revision->payment_type == 'visa' || $revision->payment_type == 'paypal') {
//                $revision->status = 'paid';
//            } else {
//                $revision->status = 'waiting';
//            }
//            $revision->payment_type = $request->payment_type;
//            $revision->bank_id = $request->bank_id;
//            $revision->bank_name = $request->bank_name;
//            $revision->bank_account_number = $request->bank_account_number;
//            $revision->bank_iban_number = $request->bank_iban_number;

            if ($request->hasFile('document')) {
                $revision->setDocumentAttribute();
            }
//            if ($request->hasFile('transfer_image')) {
//                $revision->setTransferImageAttribute();
//            }

            $revision->save();

            $revision->code = rand('111', '999') . $revision->id;
            $revision->update();

            return response()->json(['value' => true, 'data' => \Lang::get('data.yourRequestHasBeenSentToTheAdministration'), 'request_id' => $revision->id,'code'=>200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }

    public function revision_request_payment(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'payment_type' => 'required|in:visa,bank,paypal,zbony,sala',
            'image' => 'required_if:payment_type,bank|image',
            'bank_id' => 'required_if:payment_type,bank|exists:banks,id',
            'bank_name' => 'required_if:payment_type,bank',
            'bank_account_number' => 'required_if:payment_type,bank',
            'bank_iban_number' => 'required_if:payment_type,bank',
            'revision_id' => 'required|exists:revision_requests,id'
        ]);

        if ($validator->passes()) {

            $revision = RevisionRequest::find($request['revision_id']);

            $revision->completed = 'true';

            if ($revision->payment_type == 'visa' || $revision->payment_type == 'paypal') {
                $revision->status = 'paid';
            } else {
                $revision->status = 'waiting';
            }
            $revision->payment_type = $request->payment_type;
            $revision->bank_id = $request->bank_id;
            $revision->bank_name = $request->bank_name;
            $revision->bank_account_number = $request->bank_account_number;
            $revision->bank_iban_number = $request->bank_iban_number;


            if ($request->hasFile('image')) {
                $revision->setTransferImageAttribute();
            }


            $revision->update();

            return response()->json(['value' => true, 'data' => \Lang::get('data.yourRequestHasBeenSentToTheAdministration'),'code'=>200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);


    }

    public function revision_requests(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = $user->revision_requests()->where('completed','true')->latest()->paginate(10);
        return RevisionRequestResource::collection($rows)->additional(['value' => true,'code'=>200]);
    }

    public function single_revision_request(Request $request, $id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $row = RevisionRequest::find($id);
        return response()->json(['value' => true, 'data' => new RevisionRequestResource($row),'code'=>200]);
    }

}
