<?php

namespace App\Http\Resources;

use App\Models\CourseRequest;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class MyCourseResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $status = CourseRequest::where(['course_id' => $this->id, 'user_id' => $user->id])->first();

        $status_words = ['pending' => 'فى انتظار تاكيد الاداره', 'accepted' => 'تم الموافقه', 'refused' => 'تم الرفض'];
        return [
            'id' => $this->id,
            'title' => $this->title[$lang],
            'category_id' => $this->category_id,
            'category_name' => $this->category->name[$lang],
            'description' => $this->description[$lang],
            'paid' => $this->paid,
            'price' => $this->price ? $this->price : '',
            'start_date' => $this->start_date,
            'end_date' => $this->end_date,
            'course_code' => $this->course_code,
            'zoom_link' => $this->zoom_link ? $this->zoon_link  : '',
            'image' => $this->image,
            'course_rate' => getRate($this->id, 'course'),
            'teacher_rate' => getRate($this->id, 'teacher'),
            'status' => $lang == 'ar' ? $status_words[$status->admin_accept] : $status->admin_accept,
            'days' => DayResource::collection($this->days()->get()),
            'documents' => DocumentResource::collection($this->documents()->get())
        ];
    }
}
