<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;

class Course extends Model
{

    protected $table = 'courses';
    public $timestamps = true;
    protected $fillable = array('title', 'category_id', 'description', 'paid', 'price', 'start_date', 'end_date', 'course_code', 'zoom_link', 'image');
    protected $casts = ['title' => 'json', 'description' => 'json'];
    protected $appends = ['student_count'];
    public function getStudentCountAttribute()
    {
        return UserCourse::whereCourseId($this->id)->count();
    }

    public function setImageAttribute()
    {
        $file = request()->file('image');
        $destinationPath = 'images/courses/';
        $filename = time() . '.' . $file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['image'] = $filename;
    }

    public function getImageAttribute()
    {
        if ($this->attributes['image']) {
            return asset('images/courses/') . '/' . $this->attributes['image'];
        }
        return asset('logo.png');
    }

    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function documents()
    {
        return $this->hasMany(CourseDocument::class, 'course_id');
    }

    public function days()
    {
        return $this->hasMany(CourseDay::class, 'course_id');
    }

    public function students()
    {
        return $this->belongsToMany(User::class, 'user_courses', 'course_id', 'user_id');
    }
}
